package
Version:
v0.0.0-...-04c5f57
Opens a new window with list of versions in this module.
Published: Jul 3, 2018
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Brokers []string
Port int
}
Application configuration
func LoadConfigFromEnvironment() Config
Loading configuration from environment variables
Source Files
¶
Click to show internal directories.
Click to hide internal directories.